@@ -1,3 +1,4 @@
+#!/usr/bin/env python2
 import time, pdb
 from subprocess import call
 
@@ -77,9 +78,50 @@ def play_sound(args,printer):
     #call(cmd)
 
 
+#########################
+## TESTS
+
+def _tests():
+    test_trim_leading_dashes()
+    test_begins_with_dash ()
+
+def test_trim_leading_dashes():
+    strng = "-abc"
+    result = trim_leading_dashes(strng)
+    assert result == "abc"
+    strng = "--abc"
+    result = trim_leading_dashes(strng)
+    assert result == "abc"
+    strng = "abc"
+    result = trim_leading_dashes(strng)
+    assert result == "abc"
+
+def test_begins_with_dash ():
+    strng = "-abc"
+    result = begins_with_dash(strng)
+    assert result == True
+    strng = "--abc"
+    result = begins_with_dash(strng)
+    assert result == True
+    strng = "abc"
+    result = begins_with_dash(strng)
+    assert result == False
+    
 ##########################
 ## HELPERS
 
+
+def trim_leading_dashes(strng):
+    # pdb.set_trace()
+    while begins_with_dash(strng):
+        strng = strng[1:]
+    return strng
+
+def begins_with_dash(strng):
+    if strng[0] == '-':
+        return True
+    return False
+
 def monitored_channel(channel, monitored_channels):
     for mon_channel, last_chatted in monitored_channels.items():
         if channel == mon_channel:
@@ -94,7 +136,8 @@ def construct_alert(frm, channel, msg, elapsed=None):
     message = msg
     if elapsed:
         message += u" (" + unicode(round(seconds_listen_channel - elapsed)) + u"s left)"
-    return alert_title, message
+    return trim_leading_dashes(alert_title), trim_leading_dashes(message)
+
 
 def get_elapsed_time_on_channel(channel, monitored_channels):
     last_chatted = monitored_channels[channel]
@@ -164,3 +207,6 @@ def printall(incoming_message, response_actions, start_time):
 def print_sep(dur):
     print("-------------------------------")
     time.sleep(dur)
+
+if __name__ == '__main__':
+    _tests()
